package betterquesting.api2.client.gui.panels.content;

import betterquesting.api.utils.RenderUtils;
import betterquesting.api2.client.gui.misc.IGuiRect;
import betterquesting.api2.client.gui.panels.IGuiPanel;
import betterquesting.api2.client.gui.resources.colors.GuiColorStatic;
import betterquesting.api2.client.gui.resources.colors.IGuiColor;
import java.util.List;
import net.minecraft.client.Minecraft;
import net.minecraft.client.gui.FontRenderer;
import net.minecraft.util.MathHelper;
import org.lwjgl.opengl.GL11;

/* loaded from: betterquesting_api2_client_gui_panels_content.jar:betterquesting/api2/client/gui/panels/content/PanelTextBox.class */
public class PanelTextBox implements IGuiPanel {
    private final GuiRectText transform;
    private boolean enabled;
    private String text;
    private boolean shadow;
    private IGuiColor color;
    private final boolean autoFit;
    private int align;
    private int fontScale;
    private int lines;

    public PanelTextBox(IGuiRect rect, String text) {
        this(rect, text, false);
    }

    public PanelTextBox(IGuiRect rect, String text, boolean autoFit) {
        this.enabled = true;
        this.text = "";
        this.shadow = false;
        this.color = new GuiColorStatic(255, 255, 255, 255);
        this.align = 0;
        this.fontScale = 12;
        this.lines = 1;
        this.transform = new GuiRectText(rect, autoFit);
        setText(text);
        this.autoFit = autoFit;
    }

    public PanelTextBox setText(String text) {
        this.text = text;
        IGuiRect bounds = getTransform();
        FontRenderer fr = Minecraft.func_71410_x().field_71466_p;
        if (this.autoFit) {
            List<String> sl = fr.func_78271_c(text, bounds.getWidth());
            this.lines = sl.size() - 1;
            this.transform.h = fr.field_78288_b * sl.size();
        } else {
            this.lines = (bounds.getHeight() / fr.field_78288_b) - 1;
        }
        return this;
    }

    public PanelTextBox setColor(IGuiColor color) {
        this.color = color;
        return this;
    }

    public PanelTextBox setAlignment(int align) {
        this.align = MathHelper.func_76125_a(align, 0, 2);
        return this;
    }

    public PanelTextBox setFontSize(int size) {
        this.fontScale = size;
        return this;
    }

    public PanelTextBox enableShadow(boolean enable) {
        this.shadow = enable;
        return this;
    }

    public IGuiRect getTransform() {
        return this.transform;
    }

    public void initPanel() {
        IGuiRect bounds = getTransform();
        FontRenderer fr = Minecraft.func_71410_x().field_71466_p;
        float scale = this.fontScale / 12.0f;
        if (!this.autoFit) {
            this.lines = ((int) Math.floor(bounds.getHeight() / (fr.field_78288_b * scale))) - 1;
            return;
        }
        List<String> sl = fr.func_78271_c(this.text, (int) Math.floor(bounds.getWidth() / scale));
        this.lines = sl.size() - 1;
        this.transform.h = (int) Math.floor(fr.field_78288_b * sl.size() * scale);
    }

    public void setEnabled(boolean state) {
        this.enabled = state;
    }

    public boolean isEnabled() {
        return this.enabled;
    }

    public void drawPanel(int mx, int my, float partialTick) {
        IGuiRect bounds = getTransform();
        FontRenderer fr = Minecraft.func_71410_x().field_71466_p;
        float s = this.fontScale / 12.0f;
        int w = (int) Math.ceil(RenderUtils.getStringWidth(this.text, fr) * s);
        int bw = (int) Math.floor(bounds.getWidth() / s);
        if (bw <= 0) {
            return;
        }
        GL11.glPushMatrix();
        GL11.glTranslatef(bounds.getX(), bounds.getY(), 1.0f);
        GL11.glScalef(s, s, 1.0f);
        if (this.align == 2 && bw >= w) {
            RenderUtils.drawSplitString(fr, this.text, bw - w, 0, bw, this.color.getRGB(), this.shadow, 0, this.lines);
        } else if (this.align == 1 && bw >= w) {
            RenderUtils.drawSplitString(fr, this.text, (bw / 2) - (w / 2), 0, bw, this.color.getRGB(), this.shadow, 0, this.lines);
        } else {
            RenderUtils.drawSplitString(fr, this.text, 0, 0, bw, this.color.getRGB(), this.shadow, 0, this.lines);
        }
        GL11.glPopMatrix();
    }

    public boolean onMouseClick(int mx, int my, int click) {
        return false;
    }

    public boolean onMouseRelease(int mx, int my, int click) {
        return false;
    }

    public boolean onMouseScroll(int mx, int my, int scroll) {
        return false;
    }

    public boolean onKeyTyped(char c, int keycode) {
        return false;
    }

    public List<String> getTooltip(int mx, int my) {
        return null;
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: betterquesting_api2_client_gui_panels_content.jar:betterquesting/api2/client/gui/panels/content/PanelTextBox$GuiRectText.class */
    public static class GuiRectText implements IGuiRect {
        private final IGuiRect proxy;
        private final boolean useH;
        private int h;

        public GuiRectText(IGuiRect proxy, boolean useH) {
            this.proxy = proxy;
            this.useH = useH;
        }

        public int getX() {
            return this.proxy.getX();
        }

        public int getY() {
            return this.proxy.getY();
        }

        public int getWidth() {
            return this.proxy.getWidth();
        }

        public int getHeight() {
            return this.useH ? this.h : this.proxy.getHeight();
        }

        public int getDepth() {
            return this.proxy.getDepth();
        }

        public IGuiRect getParent() {
            return this.proxy.getParent();
        }

        public void setParent(IGuiRect rect) {
            this.proxy.setParent(rect);
        }

        public boolean contains(int x, int y) {
            int x1 = getX();
            int x2 = x1 + getWidth();
            int y1 = getY();
            int y2 = y1 + getHeight();
            return x >= x1 && x < x2 && y >= y1 && y < y2;
        }

        public int compareTo(IGuiRect o) {
            return this.proxy.compareTo(o);
        }
    }
}
